Index: uspace/lib/ui/test/scrollbar.c
===================================================================
--- uspace/lib/ui/test/scrollbar.c	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/test/scrollbar.c	(revision 10fc93c16560fdc34ca9ac37d93d5aa3511c7dcd)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -284,6 +284,6 @@
 }
 
-/** ui_scrollbar_through_length() gives correct scrollbar through length */
-PCUT_TEST(through_length)
+/** ui_scrollbar_trough_length() gives correct scrollbar trough length */
+PCUT_TEST(trough_length)
 {
 	ui_t *ui = NULL;
@@ -316,5 +316,5 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	length = ui_scrollbar_through_length(scrollbar);
+	length = ui_scrollbar_trough_length(scrollbar);
 
 	/* Total length minus buttons */
@@ -620,6 +620,6 @@
 }
 
-/** Press and release up through */
-PCUT_TEST(up_through_press_release)
+/** Press and release upper trough */
+PCUT_TEST(upper_trough_press_release)
 {
 	ui_t *ui = NULL;
@@ -654,8 +654,8 @@
 	ui_scrollbar_set_cb(scrollbar, &test_scrollbar_cb, &resp);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
-
-	ui_scrollbar_up_through_press(scrollbar);
-	PCUT_ASSERT_TRUE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
+
+	ui_scrollbar_upper_trough_press(scrollbar);
+	PCUT_ASSERT_TRUE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_TRUE(resp.page_up);
 
@@ -665,13 +665,13 @@
 
 	ui_scrollbar_release(scrollbar, &pos);
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
-
-	ui_scrollbar_destroy(scrollbar);
-	ui_window_destroy(window);
-	ui_destroy(ui);
-}
-
-/** Press and release down through */
-PCUT_TEST(down_through_press_release)
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
+
+	ui_scrollbar_destroy(scrollbar);
+	ui_window_destroy(window);
+	ui_destroy(ui);
+}
+
+/** Press and release lower trough */
+PCUT_TEST(lower_trough_press_release)
 {
 	ui_t *ui = NULL;
@@ -706,8 +706,8 @@
 	ui_scrollbar_set_cb(scrollbar, &test_scrollbar_cb, &resp);
 
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
-
-	ui_scrollbar_down_through_press(scrollbar);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
+
+	ui_scrollbar_lower_trough_press(scrollbar);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_TRUE(resp.page_down);
 
@@ -717,13 +717,13 @@
 
 	ui_scrollbar_release(scrollbar, &pos);
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
-
-	ui_scrollbar_destroy(scrollbar);
-	ui_window_destroy(window);
-	ui_destroy(ui);
-}
-
-/** Updating state of throughs when cursor or thumb moves */
-PCUT_TEST(throughs_update)
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
+
+	ui_scrollbar_destroy(scrollbar);
+	ui_window_destroy(window);
+	ui_destroy(ui);
+}
+
+/** Updating state of troughs when cursor or thumb moves */
+PCUT_TEST(troughs_update)
 {
 	ui_t *ui = NULL;
@@ -754,11 +754,11 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	PCUT_ASSERT_FALSE(scrollbar->down_through_inside);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_inside);
 
 	pos.x = 60;
 	pos.y = 22;
 
-	ui_scrollbar_throughs_update(scrollbar, &pos);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_inside);
+	ui_scrollbar_troughs_update(scrollbar, &pos);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_inside);
 
 	ui_scrollbar_destroy(scrollbar);
@@ -1082,6 +1082,6 @@
 }
 
-/** ui_scrollbar_pos_event() detects up through press/release */
-PCUT_TEST(pos_event_press_release_up_through)
+/** ui_scrollbar_pos_event() detects upper trough press/release */
+PCUT_TEST(pos_event_press_release_upper_trough)
 {
 	ui_t *ui = NULL;
@@ -1107,5 +1107,5 @@
 	PCUT_ASSERT_ERRNO_VAL(EOK, rc);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 
 	rect.p0.x = 20;
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
 	/* Need to move thumb so that up through can be accessed */
 	ui_scrollbar_set_pos(scrollbar, 42);
 
 	/* Press inside up through is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 50;
 	event.vpos = 20;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_TRUE(scrollbar->up_through_held);
+	PCUT_ASSERT_TRUE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
 	/* Release outside (or anywhere) is claimed and relases up through */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
 	event.vpos = 32;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
@@ -1139,6 +1139,6 @@
 }
 
-/** ui_scrollbar_pos_event() detects down through press/release */
-PCUT_TEST(pos_event_press_release_down_through)
+/** ui_scrollbar_pos_event() detects lower trough press/release */
+PCUT_TEST(pos_event_press_release_lower_trough)
 {
 	ui_t *ui = NULL;
@@ -1164,5 +1164,5 @@
 	PCUT_ASSERT_ERRNO_VAL(EOK, rc);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 
 	rect.p0.x = 20;
@@ -1172,18 +1172,18 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
 	/* Press inside down through is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 70;
 	event.vpos = 20;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_held);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
 	/* Release outside (or anywhere) is claimed and relases up through */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
 	event.vpos = 32;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	/* Need to move thumb so that up through can be accessed */
+	/* Need to move thumb so that upper trough can be accessed */
 	ui_scrollbar_set_pos(scrollbar, 42);
 
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_pos(scrollbar, 42);
 
-	/* Press inside up through is claimed and depresses it */
+	/* Press inside upper trough is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 50;
@@ -1115,21 +1115,21 @@
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
-	/* Release outside (or anywhere) is claimed and relases up through */
+	/* Release outside (or anywhere) is claimed and relases upper trough */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
@@ -1172,18 +1172,18 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	/* Press inside down through is claimed and depresses it */
+	/* Press inside lower trough is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 70;
@@ -1172,18 +1172,18 @@
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
-	/* Release outside (or anywhere) is claimed and relases up through */
+	/* Release outside (or anywhere) is claimed and relases upper trough */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
